package de.intevation.flys.artifacts.states;

import java.util.List;

import org.apache.log4j.Logger;

import de.intevation.artifacts.CallContext;

import de.intevation.artifactdatabase.state.Facet;

import de.intevation.flys.artifacts.FLYSArtifact;
import de.intevation.flys.artifacts.WINFOArtifact;
import de.intevation.flys.artifacts.model.FacetTypes;
import de.intevation.flys.artifacts.model.WaterlevelFacet;
import de.intevation.flys.artifacts.model.WQKms;
import de.intevation.flys.artifacts.resources.Resources;

/**
 * The final state that will be reached after the discharge curve calculation
 * mode has been chosen.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class ComputedDischargeCurveState
extends      DefaultState
implements   FacetTypes
{
    /** The logger that is used in this state.*/
    private static Logger logger =
        Logger.getLogger(ComputedDischargeCurveState.class);

    public ComputedDischargeCurveState() {
    }


    @Override
    public Object computeAdvance(
        FLYSArtifact artifact,
        String       hash,
        CallContext  context,
        List<Facet>  facets, 
        Object       old
    ) {
        WINFOArtifact winfo = (WINFOArtifact)artifact;

        WQKms res;

        if (old instanceof WQKms []) {
            res = ((WQKms [])old)[0];
        }
        else {
            res = winfo.getComputedDischargeCurveData();

            if (res == null) {
                logger.debug("No results given.");
                return null;
            }
        }

        Object[] args = new Object[] {
            winfo.getRiver().getName(),
            res.getName()
        };

        String name = Resources.getMsg(
            context.getMeta(),
            "chart.computed.discharge.curve.curve.label",
            "",
            args);

        Facet q = new WaterlevelFacet(0, COMPUTED_DISCHARGE_Q, name);

        facets.add(q);

        return new WQKms[] { res };
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
